@@ -43,7 +43,7 @@ sub aggregate {
         my $res = $ua->mirror("http://youtube.com/results?search_type=search_videos&search_query=$q&search_sort=$sort&search_category=0&page=$_" => $file);
 
         if($res->is_error){
-            $context->log( error => $res->status_line );
+            $context->log( error => $res->status );
             return;
         }
 
@@ -65,8 +65,8 @@ sub aggregate {
                 };
             m!<img src="(http://[\w-]*static\d+(.[\w-]+)?\.youtube.com/[^">]+/[12].jpg)" class="vimg120" />!
                 and $data->{image}->{url} = $1;
-            m!<div class="vdesc">(.*)</div>!
-                and $data->{description} = $1;
+            m!<div class="vdesc">!
+                and $data->{description} = <$fh>;
             m!<div class="vtagLabel">Tags:</div>!
                 and $tag_flag = 1;
             m!(<a href="/results\?search_type=.*)!
@@ -102,7 +102,7 @@ sub aggregate {
                         "item-" . $entry->link, sub {
                             my $res = $ua->fetch($entry->link);
                             if ($res->is_error){
-                                $context->log( error => $res->status_line );
+                                $context->log( error => $res->status );
                                 return;
                             }
                             my $url;
